<?php

namespace App\Security\Handler;

use App\Entity\GlobalParameter;
use App\Tools\RoleCheck;
use Doctrine\ORM\EntityManagerInterface;
use Sonata\AdminBundle\Admin\AdminInterface;
use Sonata\AdminBundle\Security\Handler\RoleSecurityHandler;
use Symfony\Component\Security\Core\Exception\AuthenticationCredentialsNotFoundException;

class VoterSecurityHandler extends RoleSecurityHandler
{
    protected $manager;
    protected $rolecheck;

    /**
     * {@inheritdoc}
     */
    public function isGranted(AdminInterface $admin, $attributes, $object = null)
    {
        if (!\is_array($attributes)) {
            $attributes = [$attributes];
        }

        foreach ($attributes as $pos => $attribute) {
            $attributes[$pos] = sprintf($this->getBaseRole($admin), $attribute);
        }

        $allRole = sprintf($this->getBaseRole($admin), 'ALL');

        $isWordpress = $this->manager->getRepository(GlobalParameter::class)->val(GlobalParameter::USE_WORDPRESS) != 'false';
        if ($isWordpress) {
            foreach ($attributes as $attribute) {
                if (strpos($attribute, 'ROLE_ADMIN_FAQ') !== false
                    || strpos($attribute, 'ROLE_ADMIN_PAGE') !== false
                    || strpos($attribute, 'ROLE_ADMIN_DOCUMENT') !== false
                    || strpos($attribute, 'ROLE_PRODIGIOUS_SONATA_MENU') !== false
                    || strpos($attribute, 'ROLE_ADMIN_NEWS') !== false) {
                    return false;
                }
            }
        }
        try {
            return $this->isAnyGranted($this->superAdminRoles)
                || $this->isAnyGranted($attributes, $object)
                || $this->isAnyGranted([$allRole], $object);
        } catch (AuthenticationCredentialsNotFoundException $e) {
            return false;
        }
    }

    public function setManager(EntityManagerInterface $manager)
    {
        $this->manager = $manager;
    }

    public function setRolecheck(RoleCheck $rolecheck)
    {
        $this->rolecheck = $rolecheck;
    }

    private function isAnyGranted(array $attributes, $subject = null): bool
    {
        // $user = $this->tokenStorageInterface->getToken()->getUser();
        foreach ($attributes as $attribute) {
            if ($this->authorizationChecker->isGranted($attribute, $subject)) {
                return true;
            }
        }

        return false;
    }
}
